@@ -18,8 +18,8 @@
 
 // Version of the language:
 #define OSL_VERSION_MAJOR 1
-#define OSL_VERSION_MINOR 13
-#define OSL_VERSION_PATCH 12
+#define OSL_VERSION_MINOR 14
+#define OSL_VERSION_PATCH 5
 #define OSL_VERSION_TWEAK 0
 #define OSL_VERSION (10000 * OSL_VERSION_MAJOR + \
                                100 * OSL_VERSION_MINOR + \
@@ -27,8 +27,8 @@
 
 // Version of this library:
 #define OSL_LIBRARY_VERSION_MAJOR 1
-#define OSL_LIBRARY_VERSION_MINOR 13
-#define OSL_LIBRARY_VERSION_PATCH 12
+#define OSL_LIBRARY_VERSION_MINOR 14
+#define OSL_LIBRARY_VERSION_PATCH 5
 #define OSL_LIBRARY_VERSION_TWEAK 0
 #define OSL_LIBRARY_VERSION_RELEASE_TYPE 
 
@@ -66,17 +66,33 @@
 
 
 // Establish the name spaces
-namespace OSL_v1_13 { }
-namespace OSL = OSL_v1_13;
-
-// Macros to use in each file to enter and exit the right name spaces.
-#define OSL_NAMESPACE OSL_v1_13
-#define OSL_NAMESPACE_STRING "OSL_v1_13"
-#define OSL_NAMESPACE_ENTER namespace OSL_v1_13 {
-#define OSL_NAMESPACE_EXIT }
+namespace OSL {
+    // Current version's new inner namespace is inline so it's used by default.
+    inline namespace v1_14 { }
+    // Legacy namespaces:
+    // namespace v1_13 { }
+}
+#define OSL_CUSTOM_OUTER_NAMESPACE 0
+#if OSL_CUSTOM_OUTER_NAMESPACE
+namespace OSL = OSL;
+#endif
 
 
-// Which CPP standard (11, 14, etc.) was this copy of OIIO *built* with?
+// Macros to declare things in the current version's inline namespace.
+#define OSL_NAMESPACE_BEGIN namespace OSL { inline namespace v1_14 {
+#define OSL_NAMESPACE_END } }
+#define OSL_CURRENT_NAMESPACE OSL::v1_14
+
+// Macros for defining legacy namespaces with an explicit version
+#define OSL_NS_BEGIN(ver) namespace OSL { namespace ver {
+#define OSL_NS_END } }
+
+// Legacy definitions, DEPRECATED(1.14)
+#define OSL_NAMESPACE_ENTER OSL_NAMESPACE_BEGIN
+#define OSL_NAMESPACE_EXIT OSL_NAMESPACE_END
+
+
+// Which CPP standard (11, 14, etc.) was this copy of OSL *built* with?
 #define OSL_BUILD_CPP 17
 
 // DEPRECATED(2.1): old macros separately giving compatibility.
@@ -84,6 +100,7 @@ namespace OSL = OSL_v1_13;
 #define OSL_BUILD_CPP14 (17 >= 14)
 #define OSL_BUILD_CPP17 (17 >= 17)
 #define OSL_BUILD_CPP20 (17 >= 20)
+#define OSL_BUILD_CPP23 (17 >= 20)
 
 #define OSL_SHADER_INSTALL_DIR "/usr/share/OSL/shaders"
 
